#ifndef treemenu_h
#define treemenu_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_treemenu: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_treemenu */
public:
	MODULE_treemenu (void);
	int dohtml (const char *key);
	int execmain (int argc, char *argv[], bool);
	int message (const char *msg,
		 int argc,
		 const char *argv[]);
    /*~PROTOEND~ MODULE_treemenu */
};

#include "treemenu.p"

#endif
